FijkValue class
FijkValue include the properties of a FijkPlayer which update not frequently.
To get the updated value of other frequently updated properties, add listener of the value stream. See
- Annotations
Constructors
- FijkValue({required bool prepared, required bool completed, required bool audioRenderStart, required bool videoRenderStart, required FijkState state, required Size? size, required int rotate, required Duration duration, required bool fullScreen, required FijkException exception, required double volumne})
-
A constructor requires all value.
const
- FijkValue.uninitialized()
-
Construct FijkValue with uninitialized value
const
Properties
- audioRenderStart → bool
-
Indicates if audio is started rendering
final
- completed → bool
-
Indicates if the player is completed
final
- duration → Duration
-
The current playback duration
final
- exception → FijkException
-
final
- fullScreen → bool
-
whether if player should be displayed in full screen mode
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- prepared → bool
-
Indicates if the player is ready
final
- rotate → int
-
The rotation degrees
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → Size?
-
The pixel size of current video
final
- state → FijkState
-
Current state of the player
final
- videoRenderStart → bool
-
Indicates if video is started rendering
final
- volumne → double
-
final
Methods
-
copyWith(
{bool? prepared, bool? completed, bool? videoRenderStart, bool? audioRenderStart, FijkState? state, Size? size, int? rotate, Duration? duration, bool? fullScreen, FijkException? exception, double? volumne}) → FijkValue - Return new FijkValue which combines the old value and the assigned new value
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override